.. _training_data_parts:

TrainingDataParts
=================

.. py:module:: ansys.simai.core.data.training_data_parts

A :class:`TrainingDataPart<ansys.simai.core.data.training_data_parts.TrainingDataPart>` instance
is a singular file that is part of a :class:`~ansys.simai.core.data.training_data.TrainingData`
instance.

Directory
---------

.. autoclass:: TrainingDataPartDirectory
    :members:

Model
-----

.. autoclass:: TrainingDataPart
    :members:
    :inherited-members:
